pub enum Error {
Bech32(Error),
InvalidHumanReadablePart,
ScriptPubkeyTooShort,
ScriptPubkeyInvalidLength,
InvalidLength,
InvalidVersionLength,
InvalidScriptVersion,
InvalidEncoding,
}Expand description
Error types for witness programs
BIP141 specifies Segregated Witness and defines valid program lengths for Version 0 scripts. Script version is also limited to values 0-16.
Variants
Bech32(Error)
Some Bech32 conversion error
InvalidHumanReadablePart
The human-readable part is invalid (must be “bc” or “tb”)
ScriptPubkeyTooShort
scriptpubkeys does not have enough data
ScriptPubkeyInvalidLength
The provided length byte does not match the data
InvalidLength
Denotes that the WitnessProgram is too long or too short
Programs must be between 2 and 40 bytes
InvalidVersionLength
Given the program version, the length is invalid
Version 0 scripts must be either 20 or 32 bytes
InvalidScriptVersion
Script version must be 0 to 16 inclusive
InvalidEncoding
Improper encoding used for address
Witness version 0 addresses must use Bech32 encoding, and all other versions must use Bech32m