Struct bitcoin_bech32::WitnessProgram [−][src]
pub struct WitnessProgram { /* fields omitted */ }Witness version and program data
Methods
impl WitnessProgram[src]
impl WitnessProgrampub fn new(
version: u5,
program: Vec<u8>,
network: Network
) -> Result<WitnessProgram, Error>[src]
pub fn new(
version: u5,
program: Vec<u8>,
network: Network
) -> Result<WitnessProgram, Error>Construct a new WitnessProgram given the constituent version, witness program and network version
pub fn to_address(&self) -> String[src]
pub fn to_address(&self) -> StringConverts a Witness Program to a SegWit Address
pub fn from_address(address: &str) -> Result<WitnessProgram, Error>[src]
pub fn from_address(address: &str) -> Result<WitnessProgram, Error>Decodes a segwit address into a Witness Program
Verifies that the address contains a known human-readable part
hrp and decodes as proper Bech32-encoded string. Allowed values of
the human-readable part correspond to the defined types in constants
pub fn to_scriptpubkey(&self) -> Vec<u8>[src]
pub fn to_scriptpubkey(&self) -> Vec<u8>Converts a WitnessProgram to a script public key
The format for the output is
[version, program length, <program>]
pub fn from_scriptpubkey(
pubkey: &[u8],
network: Network
) -> Result<WitnessProgram, Error>[src]
pub fn from_scriptpubkey(
pubkey: &[u8],
network: Network
) -> Result<WitnessProgram, Error>Extracts a WitnessProgram out of a provided script public key
pub fn validate(&self) -> Result<(), Error>[src]
pub fn validate(&self) -> Result<(), Error>Validates the WitnessProgram against version and length constraints
pub fn version(&self) -> u5[src]
pub fn version(&self) -> u5Witness program version
pub fn program(&self) -> &[u8][src]
pub fn program(&self) -> &[u8]Witness program serialized as 8-bit bytes
pub fn network(&self) -> Network[src]
pub fn network(&self) -> NetworkWhich network this witness program is intended to be run on